version 14
clear
set more off
  quietly log
  local logon = r(status)
  if "`logon'" == "on" { 
        log close 
        }
log using comp02data, text replace

/*      *****************************************************************       */
/*      Author:         Frederick J. Boehmke                                    */
/*      Date:           January 6, 2020                                         */
/*      File:           comp02data.do                                           */
/*      Purpose:        Reading in, cleaning, and reshaping data.               */
/*      Input file:     https://myweb.uiowa.edu/fboehmke/stata2020-01/pop.csv,  */
/*                      https://myweb.uiowa.edu/fboehmke/stata2020-01/pci.csv   */
/*      Output File:    comp02data.dta,                                         */
/*                      comp02data.log                                          */
/*      Requires                                                                */
/*      *****************************************************************       */

        /************************************************/
        /* Read in the data set and see what we have.   */
        /************************************************/

import delimited using https://myweb.uiowa.edu/fboehmke/stata2020-01/pop.csv, clear

                /* add -varnames- option to tell it variable names are in the first row. */
                /* And -case- option to keep those names lower case (my preference). */

import delimited using https://myweb.uiowa.edu/fboehmke/stata2020-01/pop.csv, clear ///
        delimiter(",") case(lower) varnames(1)

                /* Now view the data itself. */

  summarize     /* Note that some of the variables have no valid numeric observations. */
  
  describe      /* This is because they are string variables. */

  list areaname v4 v25          /* But they have data, just in the wrong format. */

  browse                        /* Now we can see all the data. */
                
                
        /************************************************/
        /* Now start cleaning the data up.              */
        /************************************************/

                /* We don't need this variable. */
  
drop populationsup1sup
  
                /* Rename the year variables since numbers don't work when the data were read in. */
  
rename v# pop#, addnumber(1929)
        
rename areaname state_name
rename fips state_fips
  
                /* Convert state_fips into a numeric variable. */

destring state_fips, replace force
                
                /* Clean up (N) values for AK and HI in first 21 years. */

destring pop1929-pop1949, replace force

                /* Get rid of any extra spaces in state_name. */
  
replace state_name=trim(itrim(state_name))
  
  drop if state_name == ""

                /* Now make sure we did it right. */

table state_name, c(sum pop1929)
table state_name, c(sum pop1929) format(%9.0f)                          /* Format numbers better. */
table state_name, c(sum pop1929) format(%9.0f) row                      /* Get total. */
table state_name if state_name!="United States", c(sum pop1929) format(%9.0f) row       /* Get total w/o US. */

                /* Get rid of aggregated observations. */
                /* Here are a few ways to do that. */
        
drop if state_name == "Far West"
drop if inlist(state_name, "Great Lakes", "Mideast")
drop if state_fips > 60

table state_name if state_name!="United States", c(sum pop1929) format(%9.0f) row       /* Now the total should match US. */
table state_name if state_name=="United States", c(sum pop1929) format(%9.0f) row       /* Now the total should match US. */


        /****************************************/
        /* Label the data and variables.        */
        /****************************************/
        
        
  label data "State population, 1929-2005 (Boehmke, 2020)"
   
        order state* pop*               /* Order the variables. */
        sort state_name                 /* Order the data. */
  
        compress                        /* Stores the data more efficiently. */ 
  
  save comp02data, replace

        
log close
clear
exit    
