version 14
clear
set more off
  quietly log
  local logon = r(status)
  if "`logon'" == "on" { 
        log close 
        }
log using comp04egen.log, text replace

/*      *********************************************************************        */
/*      File Name:      comp04egen.do                                                */
/*      Date:           January 6, 2020                                              */
/*      Author:         Frederick J. Boehmke                                         */
/*      Purpose:        Basic egen() commands in Stata.                              */
/*      Input File:     https://myweb.uiowa.edu/fboehmke/stata2020-01/comp04egen.dta */
/*      Output File:    comp04egen.log                                               */      
/*      *********************************************************************        */

        
use https://myweb.uiowa.edu/fboehmke/stata2020-01/comp04egen, clear

                /* Use egen to calculate various statistics for each state or year. */

egen pop_tot = sum(pop) if state_name!="United States", by(year)        /* Total population each year. */

                /* Check to make sure it worked. */
  
  table year if state_name!="United States", c(sum pop mean pop_tot) format(%9.0f)
        
                /* We could standardize population for each state over time. */

egen pop_mean = mean(pop), by(state_name)       /* Mean population for each state. */
egen pop_sd   = sd(pop), by(state_name)         /* SD of population for each state. */
        
  generat pop_norm = (pop - pop_mean)/pop_sd

                /* Should be mean 0 and SD 1. */
        
  table state_name, c(mean pop_norm sd pop_norm) 
  
                /* Check number of nonmissing observations for our variables. */
  
egen pop_nonmiss = count(pop), by(state_name)
egen pcpi_nonmiss = count(pcpi), by(state_name)
  
  table state_name, c(mean pop_nonmiss count pop mean pcpi_nonmiss count pcpi)
  
                /* Get percent of US population in each state 2 ways and compare. */
  
egen pop_pct = pc(pop) if state_name!="United States", by(year)

  generat pop_pct2 = 100*pop/pop_tot

  correlate pop_pct pop_pct2
  bysort state_name: correlate pop_pct pop_pct2
  
                /* Graph the results, then make it look better. */

graph bar pop_pct, over(state_nam) 
	
graph bar pop_pct if state_name!="United States", over(state_nam, label(labsize(tiny))) horizontal ytitle(Percent of Population)
		
                /* Create various id variables. */
        
sort state_name year

                /* Order each observation for each state starting at 1. */

egen order_id = seq(), from(1) by(state_name)

                /* Create unique ID for every observation. */

egen unique_id = group(state_name year)

                /* Create numeric ID for states with name as the label. */

encode state_name, generat(state_id) 
        
                /* Now inspect them. */
        
list state_* year *_id
list state_* year *_id, nolabel
        
log close
clear
