version 14
clear
set more off
  quietly log
  local logon = r(status)
  if "`logon'" == "on" { 
        log close 
        }
log using comp05loops, text replace

/*      **************************************************************************      */
/*      Author:         Frederick J. Boehmke                                            */
/*      Date:           January 6, 2020                                                 */
/*      File:           comp05loops.do                                                  */
/*      Purpose:        Working with loops.                                             */
/*      Input file:     https://myweb.uiowa.edu/fboehmke/stata2020-01/comp05loops.dta   */
/*      Output File:    comp05loops.dta,                                                */
/*                      comp05loops.log                                                 */
/*      **************************************************************************      */

        /************************************************/
        /* Examples of loops without any data.          */
        /************************************************/

                /* These are loops over numbers. */
        
forvalues i=1/15 {

  display `i'
  
  }
        
forvalues i=1(2)15 {    /* Just odd numbers. */

  display `i'
  
  }

forvalues i=3(2)15 {

  local j = `i'-1    /* Manipulate i and store in j. */

  display `i' `j'
  display "`i' `j'"  /* Quotes will include the space. */
  
  }

forvalues i=3(2)15 {

  local j = `i'-1    /* Manipulate i and store in j. */

  display `i'*`j'    /* We can manipulate as well. */
  
  }

                /* This does the same thing more easily. */
        
forvalues i=3(2)15 {

  display `i'*(`i'-1)
  
  }

                /* These are loops over strings (which may be numbers). */
                
foreach i of numlist 3(2)15 {

  display `i'*(`i'-1)
  
  }


foreach word in "apple" "pear" "banana" {

  display "`word'"

  }

                /* Accomplish the same thing with a local. */
        
local words "apple pear banana"

foreach word of local words {

  display "`word'"

  }

                /* And, of course, loops within loops. */
                
foreach state in "Iowa" "Illinois" "Nebraska" {

  forvalues year=1970/1980 {

        display "`state' `year'"
        
        }
        
  }

        
        /************************************************/
        /* Read in a data set and run some loops.       */
        /************************************************/

        
use https://myweb.uiowa.edu/fboehmke/stata2020-01/comp05loops, clear

  summarize
  
                /* Basic loop over variables. */
  
  foreach var of varlist pop pcpi rpcpi {
  
        summarize `var'
        
        }
  
                /* Get population growth one state at a time. */
  
levelsof state_name, local(states)
  
                /* Displaying locals can be tricky. */
  
  display `states'
  display `"`states'"'
        

xtset           /* Redeclare to get sorted for lag. */

levelsof state_name, local(states)

foreach state of local states {
  
        regress pop l.pop if state_name == "`state'"
        
        }
        
                /* Nice to see which state is which. */

levelsof state_name, local(states)

foreach state of local states {
  
        display "`state'"
        regress pop l.pop if state_name == "`state'"
        
        }
        
                /* Could clean it up even more. */

levelsof state_name, local(states)

foreach state of local states {
  
        quietly regress pop l.pop if state_name == "`state'"
        display _b[l.pop] " `state'"
        
        }
        
log close
clear
